==> haskell-ranged-sets-0.4.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.4.0
id: Ranged-sets-0.4.0-KgKgXSkd8dqDJ2lvLVZy5E
key: Ranged-sets-0.4.0-KgKgXSkd8dqDJ2lvLVZy5E
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008, 2019
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: c9099c4b2bc6ae2234f214d5db8819cd
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.6.5/site-local/Ranged-sets-0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Ranged-sets-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Ranged-sets-0.4.0
hs-libraries: HSRanged-sets-0.4.0-KgKgXSkd8dqDJ2lvLVZy5E
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.4.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.4.0
id: Ranged-sets-0.4.0-D27FMka9bytKUruEy8c81
key: Ranged-sets-0.4.0-D27FMka9bytKUruEy8c81
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008, 2019
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: https://github.com/PaulJohnson/Ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: 36f7179d98a01971afd8a3f9eb9cdbac
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.6.5/site-local/Ranged-sets-0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Ranged-sets-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Ranged-sets-0.4.0
hs-libraries: HSRanged-sets-0.4.0-D27FMka9bytKUruEy8c81
depends:
    HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
